package com.wasu.cs.mvp.IView;

import android.util.SparseArray;

import com.wasu.cs.model.ChildrenChannelModel;
import com.wasu.cs.model.ChildrenRecommendModel;

import java.util.List;

/**
 * Created by chenming on 2016/11/22.
 *
 * @Description: 新版少儿首页视图接口
 * @email chenming@wasu.com
 */

public interface IChildrenHomeView extends MvpView {
	void onGetInfoBar(ChildrenChannelModel.DataBean.BodyBean.InfoBarBean infoBar);
	/**
	 * 少儿卡通卡通人物循环列表
	 * @param cartoonsBeanList
	 */
	void onGetCartoons(List<ChildrenChannelModel.DataBean.BodyBean.CartoonsBean> cartoonsBeanList);

	/**
	 * 少儿频道首页入口列表
	 * @param entrysBeanList
	 */
	void onGetEntrys(List<ChildrenChannelModel.DataBean.BodyBean.EntrysBean> entrysBeanList);

	/**
	 * 回调所有少儿入口推荐资产
	 * @param
	 */

	void onGetRecommendData(SparseArray<List<ChildrenRecommendModel.DataBean.Cat>> catList);


	/**
	 * 获取数据失败后的回调方法
	 */
	void ongetDataFailed(Throwable throwable);
}
